… | OiRA

Help

1. Προετοιμασία
2. Συμμετοχή των εργαζομένων
3. Αναγνώριση + Αξιολόγηση
   1. 1 Commercial manned guarding
   2. Ω Πρόσθετοι κίνδυνοι (από το χρήστη)
      1. Ω.1 The entrance floor is often wet
      2. Ω.2 …
   - Υπό εξέταση κίνδυνος
   - Κίνδυνος σε εκκρεμότητα
   - Ασφαλής κατάσταση
   - Προσοχή κίνδυνος!
4. Σχέδιο Δράσης
5. Έκθεση
6. Παρούσα Κατάσταση 0%

## Περιγράψτε τον κίνδυνο…

Όχι, απαιτούνται περισσότερα μέτρα Ναι, ο εναπομένων κίνδυνος είναι αποδεκτός

Select the priority of this risk Low Medium High
Πληροφορίες
Φόρτωση εικόναςlabel_upload_image
Σχόλια / Υφιστάμενα μέτρα (αν υπάρχουν)

Scroll to top
Back

## add-risk.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More